==> webcamoid_7.2.1+dfsg1.orig.tar.gz: webcamoid-7.2.1+dfsg1/README.md <==
# Webcamoid, webcam capture application #

[Webcamoid](https://webcamoid.github.io/) is a full featured webcam capture application.

## Features ##

* Cross-platform (GNU/Linux, Windows)
* Take pictures and record videos with the webcam.
* Manages multiple webcams.
* Written in C++/Qt.
* Custom controls for each webcam.
* Add funny effects to the webcam.
* +60 effects available.
* Translated to many languages.
* Use custom network and local files as capture devices.
* Capture from desktop.
* Many recording formats.
* Virtual webcam support for feeding other programs.

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Status ##

[![Build Status](https://travis-ci.org/webcamoid/webcamoid.svg?branch=master)](https://travis-ci.org/webcamoid/webcamoid)[![Build status](https://ci.appveyor.com/api/projects/status/hrgbf3qe52ysr8gl?svg=true)](https://ci.appveyor.com/project/hipersayanX/webcamoid)[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)[![Total Downloads](https://img.shields.io/github/downloads/webcamoid/webcamoid/total.svg)](https://github.com/webcamoid/webcamoid/releases)[![Softpedia reviews](https://img.shields.io/badge/review-softpedia-ff69b4.svg)](http://www.softpedia.com/get/Internet/WebCam/Webcamoid.shtml)

## Reporting Bugs ##

Use Webcamoid until an abnormal event happen, write a list with the following information:

1. Your Webcamoid version.
2. Your operating system.
3. Your Qt version.
4. Your GCC/Clang version.
5. Your DE/WM version.
6. Any other useful information.

Send this list to the [issues page](http://github.com/webcamoid/webcamoid/issues). Please report **ANY** problem you have with Webcamoid in the official website, help to centralize information in one unique place.

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).

==> webcamoid_8.0.0+dfsg.orig.tar.gz: webcamoid-8.0.0/README.md <==
# Webcamoid, The ultimate webcam suite! #

[Webcamoid](https://webcamoid.github.io/) is a full featured and multiplatform webcam suite.

<a target="_blank" href="https://webcamoid.github.io/"><img src="http://webcamoid.github.io/theme/images/screenshots/cap01.png" style="height: 240px;" /></a>

## Features ##

* Cross-platform (GNU/Linux, Mac, Windows)
* Take pictures and record videos with the webcam.
* Manages multiple webcams.
* Written in C++/Qt.
* Custom controls for each webcam.
* Add funny effects to the webcam.
* +60 effects available.
* Translated to many languages.
* Use custom network and local files as capture devices.
* Capture from desktop.
* Many recording formats.
* Virtual webcam support for feeding other programs.

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Status ##

[![Build Status](https://travis-ci.org/webcamoid/webcamoid.svg?branch=master)](https://travis-ci.org/webcamoid/webcamoid)[![Build status](https://ci.appveyor.com/api/projects/status/hrgbf3qe52ysr8gl?svg=true)](https://ci.appveyor.com/project/hipersayanX/webcamoid)[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)[![Total Downloads](https://img.shields.io/github/downloads/webcamoid/webcamoid/total.svg)](https://github.com/webcamoid/webcamoid/releases)[![Softpedia reviews](https://img.shields.io/badge/review-softpedia-ff69b4.svg)](http://www.softpedia.com/get/Internet/WebCam/Webcamoid.shtml)

[![Packaging status](https://repology.org/badge/vertical-allrepos/webcamoid.svg)](https://repology.org/metapackage/webcamoid)

## Reporting Bugs ##

Use Webcamoid until an abnormal event happen, write a list with the following information:

1. Your Webcamoid version.
2. Your operating system.
3. Your Qt version.
4. Your GCC/Clang version.
5. Your DE/WM version.
6. Any other useful information.

Send this list to the [issues page](http://github.com/webcamoid/webcamoid/issues). Please report **ANY** problem you have with Webcamoid in the official website, help to centralize information in one unique place.

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).
